@@ -575,24 +575,24 @@ var NAVTREEINDEX =
 "group__pw__keys.html#ga7e12dd6c9dec4a345c8a2a62f138b5bf",
 "group__pw__module.html#ga8c4bfe6ad4da2e2443ba7985ae7527cb",
 "group__pw__resource.html#ga61e286d92a2f528ebe48cb1436ac4eba",
-"group__pw__thread__loop.html#gacb9c26a513d752803fd272a4ea2bc891",
-"group__spa__cpu.html#ga36f54e2aac3837cb3631db07cbfde3e2",
-"group__spa__hooks.html#gacb30a0a53954eed2af8041a1882eef15",
-"group__spa__names.html#ga010bfd1f2c50f4927df733f5f13e5690",
-"group__spa__param.html#ga16b81e964fbcf48dad50bdefc9465f50",
-"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586a5415212a919922d9c78af124ad709a84",
-"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81af84009598e00461443c13d3df1c67c9c",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaafe4f629b00a5085db83a12c94f61de22",
-"group__spa__pod.html#ga7820560083401bab79329a6b3b138c7d",
-"group__spa__types.html#ga690dba641d1bb8f54c7b0ca7478e53cf",
-"page_examples.html",
-"page_pulseaudio.html#autotoc_md282",
-"structpw__client__node__methods.html#a05968e322e128af7d58f1598ad61af7e",
-"structpw__impl__node__events.html#a8a268deab9a29164fc8f9b57a9ee55e7",
-"structpw__session__info.html#aa58e4f042f5cf3226d0765654439a9a3",
-"structspa__dict.html",
-"structspa__meta__cursor.html#a5f190ab6e828890a8c5b530cb9cae78d",
-"structspa__system__methods.html#a56a305f758899158e90920cf28fd41e4"
+"group__pw__thread__loop.html#gabdc2e68dfd070fe58770143f184fc026",
+"group__spa__cpu.html#ga34a7cfa724239e524fdccf570249abf3",
+"group__spa__hooks.html#gab5d20379dc8a8a17e58631045e3f6323",
+"group__spa__names.html",
+"group__spa__param.html#ga162e4f18a3415d721d749fe7967b0142",
+"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586a5103ce7ecf8e164734b6dd50f0dfeb93",
+"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81af096b47f86c0d581f5370984452f04c4",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaaf75aecd6d1e2ed22d4a5da51bfde53f5",
+"group__spa__pod.html#ga77acabfebad965007133387bed64922d",
+"group__spa__types.html#ga5d6f54a630998568dc7b1a3515a434bf",
+"page_dma_buf.html#autotoc_md301",
+"page_pulseaudio.html#autotoc_md281",
+"structpw__client__node__methods.html#a0193c45d32cc6806d8b1f4ef9c7a2740",
+"structpw__impl__node__events.html#a693dbb0bc91e07af02dc409dce738d6a",
+"structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6",
+"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0",
+"structspa__meta__cursor.html#a46bdd5e6f3d880a74ae602e596176028",
+"structspa__system__methods.html#a4cd27e2c3a8daa1705da0028af779060"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
