@@ -1,5 +1,6 @@
 var NAVTREEINDEX15 =
 {
+"group__spa__types.html#ga5d6f54a630998568dc7b1a3515a434bf":[10,8,8,12,11],
 "group__spa__types.html#ga690dba641d1bb8f54c7b0ca7478e53cf":[10,8,8,12,19],
 "group__spa__types.html#ga7991023e0704b7af71b19a08c4a023b7":[10,8,8,12,7],
 "group__spa__types.html#ga886514f37da7215fa5eebe406e2f3b37":[10,8,8,12,5],
@@ -248,6 +249,5 @@ var NAVTREEINDEX15 =
 "page_dma_buf.html#autotoc_md297":[5,10,0,4],
 "page_dma_buf.html#autotoc_md298":[5,10,1],
 "page_dma_buf.html#autotoc_md299":[5,10,2],
-"page_dma_buf.html#autotoc_md300":[5,10,3],
-"page_dma_buf.html#autotoc_md301":[5,10,4]
+"page_dma_buf.html#autotoc_md300":[5,10,3]
 };
