@@ -1,5 +1,6 @@
 var NAVTREEINDEX16 =
 {
+"page_dma_buf.html#autotoc_md301":[5,10,4],
 "page_examples.html":[7,7],
 "page_library.html":[5,9],
 "page_library.html#autotoc_md45":[5,9,0],
@@ -248,6 +249,5 @@ var NAVTREEINDEX16 =
 "page_proxy.html#sec_page_proxy_events":[8,1,5],
 "page_proxy.html#sec_page_proxy_methods":[8,1,4],
 "page_proxy.html#sec_page_proxy_overview":[8,1,0],
-"page_pulseaudio.html":[5,16],
-"page_pulseaudio.html#autotoc_md281":[5,16,0]
+"page_pulseaudio.html":[5,16]
 };
