@@ -1,5 +1,46 @@
 var NAVTREEINDEX17 =
 {
+"page_pulseaudio.html#autotoc_md281":[5,16,0],
+"page_pulseaudio.html#autotoc_md282":[5,16,0,0],
+"page_pulseaudio.html#autotoc_md283":[5,16,0,1],
+"page_pulseaudio.html#autotoc_md284":[5,16,1],
+"page_pulseaudio.html#autotoc_md285":[5,16,1,0],
+"page_pulseaudio.html#autotoc_md286":[5,16,1,1],
+"page_pulseaudio.html#autotoc_md287":[5,16,1,2],
+"page_pulseaudio.html#autotoc_md288":[5,16,1,3],
+"page_pulseaudio.html#autotoc_md289":[5,16,2],
+"page_scheduling.html":[5,11],
+"page_scheduling.html#autotoc_md108":[5,11,0],
+"page_scheduling.html#autotoc_md109":[5,11,1],
+"page_scheduling.html#autotoc_md110":[5,11,2],
+"page_scheduling.html#autotoc_md111":[5,11,2,0],
+"page_scheduling.html#autotoc_md112":[5,11,2,1],
+"page_scheduling.html#autotoc_md113":[5,11,2,2],
+"page_scheduling.html#autotoc_md114":[5,11,3],
+"page_scheduling.html#autotoc_md115":[5,11,3,0],
+"page_session_manager.html":[5,15],
+"page_session_manager.html#autotoc_md65":[5,15,0],
+"page_session_manager.html#autotoc_md66":[5,15,1],
+"page_session_manager.html#autotoc_md67":[5,15,2],
+"page_spa.html":[9],
+"page_spa.html#autotoc_md223":[9,0],
+"page_spa.html#autotoc_md224":[9,1],
+"page_spa.html#autotoc_md225":[9,2],
+"page_spa.html#autotoc_md226":[9,3],
+"page_spa_buffer.html":[9,7],
+"page_spa_design.html":[9,4],
+"page_spa_design.html#autotoc_md239":[9,4,0],
+"page_spa_design.html#autotoc_md240":[9,4,0,0],
+"page_spa_design.html#autotoc_md241":[9,4,0,1],
+"page_spa_design.html#autotoc_md242":[9,4,0,2],
+"page_spa_plugins.html":[9,5],
+"page_spa_plugins.html#autotoc_md227":[9,5,0],
+"page_spa_plugins.html#autotoc_md228":[9,5,1],
+"page_spa_plugins.html#autotoc_md229":[9,5,2],
+"page_spa_plugins.html#autotoc_md230":[9,5,3],
+"page_spa_plugins.html#autotoc_md231":[9,5,4],
+"page_spa_plugins.html#autotoc_md232":[9,5,5],
+"page_spa_plugins.html#autotoc_md233":[9,5,6],
 "page_spa_plugins.html#autotoc_md234":[9,5,7],
 "page_spa_plugins.html#autotoc_md235":[9,5,8],
 "page_spa_plugins.html#autotoc_md236":[9,5,8,0],
@@ -82,7 +123,7 @@ var NAVTREEINDEX17 =
 "param_2audio_2format_8h.html":[10,8,7,1],
 "param_2bluetooth_2type-info_8h.html":[10,8,7,7],
 "param_2format_8h.html":[10,8,7,11],
-"param_2video_2format_8h.html":[10,8,7,27],
+"param_2video_2format_8h.html":[10,8,7,29],
 "param_8h.html":[10,8,7,15],
 "parser_8h.html":[10,8,0,6],
 "permission_8h.html":[10,4,11,0],
@@ -208,46 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__client__node__events.html#ac0b5a3c66103be01b784464d4dd81fa0":[10,7,0,2,6],
 "structpw__client__node__events.html#ac5884f60926b382728097c8846dcba85":[10,7,0,2,2],
 "structpw__client__node__events.html#ad7084094ae633b01409033ba363ef78b":[10,7,0,2,1],
-"structpw__client__node__methods.html":[10,7,0,3],
-"structpw__client__node__methods.html#a0193c45d32cc6806d8b1f4ef9c7a2740":[10,7,0,3,6],
-"structpw__client__node__methods.html#a05968e322e128af7d58f1598ad61af7e":[10,7,0,3,1],
-"structpw__client__node__methods.html#a0d45045558276d9594008b5ac39ad404":[10,7,0,3,2],
-"structpw__client__node__methods.html#a1db43e226468e68a6a52292aa6a894c6":[10,7,0,3,7],
-"structpw__client__node__methods.html#acf64a3bd71fd790592e41458a4793c62":[10,7,0,3,0],
-"structpw__client__node__methods.html#ae7a71dd91cda53767aa31aa10c050244":[10,7,0,3,5],
-"structpw__client__session.html":[10,7,4,23],
-"structpw__client__session__events.html":[10,7,4,8],
-"structpw__client__session__events.html#a6005c505de498fbaaaed2dd87918773f":[10,7,4,8,0],
-"structpw__client__session__events.html#a8e823bcde1844c0857314b10069f3b8d":[10,7,4,8,1],
-"structpw__client__session__events.html#aae0dc344c9b1d62b21fb16e4fc2c9c33":[10,7,4,8,3],
-"structpw__client__session__events.html#af3eab807465363845550f89f1bb9d816":[10,7,4,8,2],
-"structpw__client__session__methods.html":[10,7,4,9],
-"structpw__client__session__methods.html#a4537bb47cfe11b27649ffe082fdd49fa":[10,7,4,9,0],
-"structpw__client__session__methods.html#a54ba399f450c8ee5b85cfba7ad4b352a":[10,7,4,9,1],
-"structpw__context.html":[10,4,2,3],
-"structpw__context__events.html":[10,4,2,1],
-"structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d":[10,4,2,1,4],
-"structpw__context__events.html#a34b60636aee5925696ca80cbbf63755e":[10,4,2,1,1],
-"structpw__context__events.html#a7ff739c9ebd412efa10756ececc1a27c":[10,4,2,1,7],
-"structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0":[10,4,2,1,5],
-"structpw__context__events.html#a9c874d491dfbdd13eb81c7b0b7561e87":[10,4,2,1,2],
-"structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c":[10,4,2,1,0],
-"structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c":[10,4,2,1,3],
-"structpw__context__events.html#af555de72a4d29b3d7c5074aa5e7ab6b0":[10,4,2,1,6],
-"structpw__control.html":[10,5,8,4],
-"structpw__control.html":[10,5,10,2],
-"structpw__control__events.html":[10,5,10,1],
-"structpw__control__events.html#a2cda9616fd4aa65d7cc2f8dc6efe69dc":[10,5,10,1,4],
-"structpw__control__events.html#a4d456606837f25ad3e55471ae23c6bdc":[10,5,10,1,0],
-"structpw__control__events.html#a4e2a4c85f61336fb837a43c931b7c5fa":[10,5,10,1,2],
-"structpw__control__events.html#ad23091c8931adf9aa85564b31e2d9ca8":[10,5,10,1,1],
-"structpw__control__events.html#adbd47ebc650888ca6235b763fa3f6ef2":[10,5,10,1,3],
-"structpw__core.html":[10,4,4,4],
-"structpw__core__events.html":[10,4,4,2],
-"structpw__core__events.html#a20931e5073a743e26c70957f85c10fd8":[10,4,4,2,3],
-"structpw__core__events.html#a28cd6e2263efb69df702822028a45df2":[10,4,4,2,8],
-"structpw__core__events.html#a590bf80a38429eef4a94d2e8b7f82e56":[10,4,4,2,4],
-"structpw__core__events.html#a7c1f8bd6078afab78aa943704efe7131":[10,4,4,2,7],
-"structpw__core__events.html#a7e1a9d6c8598cee58b622cf61432769e":[10,4,4,2,9],
-"structpw__core__events.html#a8433a5ea5115e8d914a70ba5dacd3b81":[10,4,4,2,1]
+"structpw__client__node__methods.html":[10,7,0,3]
 };
