@@ -1,5 +1,47 @@
 var NAVTREEINDEX20 =
 {
+"structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6":[10,7,4,18,1],
+"structpw__session__info.html#aa58e4f042f5cf3226d0765654439a9a3":[10,7,4,18,0],
+"structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660":[10,7,4,18,4],
+"structpw__session__methods.html":[10,7,4,11],
+"structpw__session__methods.html#a39a82c063c97d967e5ee82589c390c29":[10,7,4,11,0],
+"structpw__session__methods.html#a66e604601841f9f2252db7c4a4466f6f":[10,7,4,11,4],
+"structpw__session__methods.html#a6720d4c6b23022393bc945c656ba5fe0":[10,7,4,11,2],
+"structpw__session__methods.html#a9311ff4c5e45bce0b1a56ee64e720b09":[10,7,4,11,3],
+"structpw__session__methods.html#afeb231bfac6c5539d258eb06b22e0acf":[10,7,4,11,1],
+"structpw__stream.html":[10,0,5],
+"structpw__stream__control.html":[10,0,2],
+"structpw__stream__control.html#a40b47654929367a6a4f1b83b0b68bfb1":[10,0,2,3],
+"structpw__stream__control.html#a4167f3df47a2d2deff793d3f1f6d31d2":[10,0,2,0],
+"structpw__stream__control.html#a4541b454ba4caaf23f4e772f431294c1":[10,0,2,1],
+"structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046":[10,0,2,6],
+"structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62":[10,0,2,2],
+"structpw__stream__control.html#a925311b76a91a9034391da7343865091":[10,0,2,5],
+"structpw__stream__control.html#addabfd3b77bb0cb58bb65b779ab1b3d5":[10,0,2,4],
+"structpw__stream__events.html":[10,0,4],
+"structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb":[10,0,4,7],
+"structpw__stream__events.html#a12fa5918ff2c41cc41d5bf8ae36b3ca3":[10,0,4,3],
+"structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02":[10,0,4,11],
+"structpw__stream__events.html#a4d1ed03aa78fb2c8324ae13bc45731e3":[10,0,4,5],
+"structpw__stream__events.html#a512bd219ce44ba1a688d600773efe84b":[10,0,4,8],
+"structpw__stream__events.html#a66e43e35eb2be261520cda8a4e24098c":[10,0,4,10],
+"structpw__stream__events.html#a74aaca4c31e44dad69aba50607055419":[10,0,4,0],
+"structpw__stream__events.html#a89192aed5fcd89314bf7cc7ef6b21085":[10,0,4,2],
+"structpw__stream__events.html#aab4b9831ef563920b401b1f9daf93042":[10,0,4,9],
+"structpw__stream__events.html#abbe98bb0d78e6411d08244495f349b0b":[10,0,4,1],
+"structpw__stream__events.html#abd09d7c76b0e14a201a438f09e609b29":[10,0,4,6],
+"structpw__stream__events.html#ad60b819ff0ea17b0bd8833220cbd4a3e":[10,0,4,4],
+"structpw__thread__loop.html":[10,5,15,2],
+"structpw__thread__loop__events.html":[10,5,15,1],
+"structpw__thread__loop__events.html#a3c806806a4d07a0b3735f4b625740652":[10,5,15,1,1],
+"structpw__thread__loop__events.html#a6815fa728af5ab602c111e7c5b680387":[10,5,15,1,0],
+"structpw__time.html":[10,0,3],
+"structpw__time.html#a1ea3fa77ce4221df0d5ac3ad8fd1f6c7":[10,0,3,3],
+"structpw__time.html#a41d793c390eefc6aee165e16e0d7c898":[10,0,3,1],
+"structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff":[10,0,3,5],
+"structpw__time.html#a91dafbb38397328f8705e2bb20b7625a":[10,0,3,4],
+"structpw__time.html#a92d7a1849d4dc044d2fa64bd35a7a57d":[10,0,3,6],
+"structpw__time.html#a99e3d7963e24fbf410afa03c73465328":[10,0,3,2],
 "structpw__time.html#ad817da21bea1591d70f837c251a73468":[10,0,3,0],
 "structpw__time.html#aebd42745267531bc23e1ee34dd759607":[10,0,3,7],
 "structpw__work__queue.html":[10,5,16,1],
@@ -34,24 +76,24 @@ var NAVTREEINDEX20 =
 "structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[11,0,141,0],
 "structspa__audio__aec__methods.html#af75957ae10a92bb2253df67aa6eca97f":[11,0,141,9],
 "structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,141,2],
-"structspa__audio__info.html":[10,8,7,34],
-"structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[10,8,7,34,5],
-"structspa__audio__info.html#a0c0ba9b2cb3625fdbfa3a5f1a00639d3":[10,8,7,34,16],
-"structspa__audio__info.html#a1042e506082d62d0c5371c3d9d349a9a":[10,8,7,34,8],
-"structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410":[10,8,7,34,3],
-"structspa__audio__info.html#a41f273519b13112d24c1a7066755e3d8":[10,8,7,34,11],
-"structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75":[10,8,7,34,1],
-"structspa__audio__info.html#a5d87c4474c9eb1a61153dd460599591b":[10,8,7,34,6],
-"structspa__audio__info.html#a635122b47bf1de20dd009ecca6cdb7d3":[10,8,7,34,10],
-"structspa__audio__info.html#a755a925f66d28b0e9912482e97375b7a":[10,8,7,34,2],
-"structspa__audio__info.html#a880d36c25907b88e7ca3dc34d200c343":[10,8,7,34,15],
-"structspa__audio__info.html#a9128e8bd148abec71d6261dc5af9a7d9":[10,8,7,34,14],
-"structspa__audio__info.html#a9782c7a01047c3a1058fd8dd40c5f52b":[10,8,7,34,7],
-"structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30":[10,8,7,34,0],
-"structspa__audio__info.html#aa02a98d24c25c529d6b387ed1eb7074e":[10,8,7,34,4],
-"structspa__audio__info.html#ab9bbd067632a6e02f042dacff838c89b":[10,8,7,34,9],
-"structspa__audio__info.html#add88e2561d596e2d9d79bf772c7c6972":[10,8,7,34,12],
-"structspa__audio__info.html#ae9fd0fa99badc8be9ce0e59bb75f31f9":[10,8,7,34,13],
+"structspa__audio__info.html":[10,8,7,36],
+"structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[10,8,7,36,5],
+"structspa__audio__info.html#a0c0ba9b2cb3625fdbfa3a5f1a00639d3":[10,8,7,36,16],
+"structspa__audio__info.html#a1042e506082d62d0c5371c3d9d349a9a":[10,8,7,36,8],
+"structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410":[10,8,7,36,3],
+"structspa__audio__info.html#a41f273519b13112d24c1a7066755e3d8":[10,8,7,36,11],
+"structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75":[10,8,7,36,1],
+"structspa__audio__info.html#a5d87c4474c9eb1a61153dd460599591b":[10,8,7,36,6],
+"structspa__audio__info.html#a635122b47bf1de20dd009ecca6cdb7d3":[10,8,7,36,10],
+"structspa__audio__info.html#a755a925f66d28b0e9912482e97375b7a":[10,8,7,36,2],
+"structspa__audio__info.html#a880d36c25907b88e7ca3dc34d200c343":[10,8,7,36,15],
+"structspa__audio__info.html#a9128e8bd148abec71d6261dc5af9a7d9":[10,8,7,36,14],
+"structspa__audio__info.html#a9782c7a01047c3a1058fd8dd40c5f52b":[10,8,7,36,7],
+"structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30":[10,8,7,36,0],
+"structspa__audio__info.html#aa02a98d24c25c529d6b387ed1eb7074e":[10,8,7,36,4],
+"structspa__audio__info.html#ab9bbd067632a6e02f042dacff838c89b":[10,8,7,36,9],
+"structspa__audio__info.html#add88e2561d596e2d9d79bf772c7c6972":[10,8,7,36,12],
+"structspa__audio__info.html#ae9fd0fa99badc8be9ce0e59bb75f31f9":[10,8,7,36,13],
 "structspa__audio__info__aac.html":[11,0,143],
 "structspa__audio__info__aac.html#a16974760cfa2cbe91398d01fb7f4b947":[11,0,143,1],
 "structspa__audio__info__aac.html#a3b08334e341344e0035a7ee94a5c87a2":[11,0,143,2],
@@ -67,22 +109,22 @@ var NAVTREEINDEX20 =
 "structspa__audio__info__ape.html":[11,0,146],
 "structspa__audio__info__ape.html#a72509a439dfbe203c6c3653bed2153ed":[11,0,146,0],
 "structspa__audio__info__ape.html#a82e8f9bb5e9bd7bd014a92709a06b9f9":[11,0,146,1],
-"structspa__audio__info__dsd.html":[10,8,7,33],
-"structspa__audio__info__dsd.html#a4f11fce0402edcbe61f0b35f27396ac9":[10,8,7,33,5],
-"structspa__audio__info__dsd.html#a563add98a612fe3617a58e2cb1a703bc":[10,8,7,33,4],
-"structspa__audio__info__dsd.html#a698a141255b6d57f04d56de0fa52d170":[10,8,7,33,0],
-"structspa__audio__info__dsd.html#a72a8060d8747abb6e380e0dc0261157e":[10,8,7,33,3],
-"structspa__audio__info__dsd.html#a902dd094aab140dc3500a3a36ef967da":[10,8,7,33,2],
-"structspa__audio__info__dsd.html#a9f7ed724310d9b5a2c95607399fe3a34":[10,8,7,33,1],
+"structspa__audio__info__dsd.html":[10,8,7,35],
+"structspa__audio__info__dsd.html#a4f11fce0402edcbe61f0b35f27396ac9":[10,8,7,35,5],
+"structspa__audio__info__dsd.html#a563add98a612fe3617a58e2cb1a703bc":[10,8,7,35,4],
+"structspa__audio__info__dsd.html#a698a141255b6d57f04d56de0fa52d170":[10,8,7,35,0],
+"structspa__audio__info__dsd.html#a72a8060d8747abb6e380e0dc0261157e":[10,8,7,35,3],
+"structspa__audio__info__dsd.html#a902dd094aab140dc3500a3a36ef967da":[10,8,7,35,2],
+"structspa__audio__info__dsd.html#a9f7ed724310d9b5a2c95607399fe3a34":[10,8,7,35,1],
 "structspa__audio__info__dsp.html":[11,0,148],
 "structspa__audio__info__dsp.html#ab59df8be3387df377c8b698346aa234f":[11,0,148,0],
 "structspa__audio__info__flac.html":[11,0,149],
 "structspa__audio__info__flac.html#a3351a0cbf04538db70fac13cd630e79e":[11,0,149,1],
 "structspa__audio__info__flac.html#a9be31890542f5995b7bbe493cd29f688":[11,0,149,0],
-"structspa__audio__info__iec958.html":[10,8,7,35],
-"structspa__audio__info__iec958.html#ab4797480f2e4e7f25d19a0a42c748eac":[10,8,7,35,1],
-"structspa__audio__info__iec958.html#adc76e7bde0fc3d66ffa5a8442c3b1409":[10,8,7,35,0],
-"structspa__audio__info__iec958.html#af028b6675757cd4504ad1b11a2e746c7":[10,8,7,35,2],
+"structspa__audio__info__iec958.html":[10,8,7,37],
+"structspa__audio__info__iec958.html#ab4797480f2e4e7f25d19a0a42c748eac":[10,8,7,37,1],
+"structspa__audio__info__iec958.html#adc76e7bde0fc3d66ffa5a8442c3b1409":[10,8,7,37,0],
+"structspa__audio__info__iec958.html#af028b6675757cd4504ad1b11a2e746c7":[10,8,7,37,2],
 "structspa__audio__info__mp3.html":[11,0,151],
 "structspa__audio__info__mp3.html#a2066d86c3d391a097c57441f8c391234":[11,0,151,0],
 "structspa__audio__info__mp3.html#a9eab81f1ef553124803e7563d7ffce93":[11,0,151,1],
@@ -92,12 +134,12 @@ var NAVTREEINDEX20 =
 "structspa__audio__info__ra.html":[11,0,153],
 "structspa__audio__info__ra.html#a281cd0f54656e1ccfda03854e5d36ce2":[11,0,153,1],
 "structspa__audio__info__ra.html#aa5374f33cf4a773ca3bb779d3e199fc9":[11,0,153,0],
-"structspa__audio__info__raw.html":[10,8,7,37],
-"structspa__audio__info__raw.html#a542692f9d3518632e37ea575d13ca149":[10,8,7,37,0],
-"structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952":[10,8,7,37,3],
-"structspa__audio__info__raw.html#a696f18b889bb8a5496e16dd48f7d8e01":[10,8,7,37,1],
-"structspa__audio__info__raw.html#ac21ae45356ef4e1dbfde141937fde9c5":[10,8,7,37,4],
-"structspa__audio__info__raw.html#ae7e501bbfbef2cd75f3ae0f13719652c":[10,8,7,37,2],
+"structspa__audio__info__raw.html":[10,8,7,39],
+"structspa__audio__info__raw.html#a542692f9d3518632e37ea575d13ca149":[10,8,7,39,0],
+"structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952":[10,8,7,39,3],
+"structspa__audio__info__raw.html#a696f18b889bb8a5496e16dd48f7d8e01":[10,8,7,39,1],
+"structspa__audio__info__raw.html#ac21ae45356ef4e1dbfde141937fde9c5":[10,8,7,39,4],
+"structspa__audio__info__raw.html#ae7e501bbfbef2cd75f3ae0f13719652c":[10,8,7,39,2],
 "structspa__audio__info__vorbis.html":[11,0,155],
 "structspa__audio__info__vorbis.html#a7614ad24e4491223d0d44c1931c3089b":[11,0,155,0],
 "structspa__audio__info__vorbis.html#afec5882d3af8e9d177b4b0771c176046":[11,0,155,1],
@@ -107,9 +149,9 @@ var NAVTREEINDEX20 =
 "structspa__audio__info__wma.html#a328501d7905f732937932d3731916a55":[11,0,156,3],
 "structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2":[11,0,156,2],
 "structspa__audio__info__wma.html#ad572e9079c943a87b18d96060ced5af4":[11,0,156,0],
-"structspa__audio__layout__info.html":[10,8,7,36],
-"structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[10,8,7,36,1],
-"structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[10,8,7,36,0],
+"structspa__audio__layout__info.html":[10,8,7,38],
+"structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[10,8,7,38,1],
+"structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[10,8,7,38,0],
 "structspa__buffer.html":[10,8,1,7],
 "structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b":[10,8,1,7,0],
 "structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[10,8,1,7,2],
@@ -207,47 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__device__object__info.html#a0758afd0518197c48d5d76cdc14526e3":[10,8,4,5,0],
 "structspa__device__object__info.html#a4ed767ff310d6f2e1d4cd78f3a7c3f6f":[10,8,4,5,1],
 "structspa__device__object__info.html#a702111c5873243c93551073552863666":[10,8,4,5,3],
-"structspa__device__object__info.html#a9b6645d2c0b8b3679833ad122cb299a1":[10,8,4,5,2],
-"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0":[10,8,4,5,4],
-"structspa__dict.html":[10,8,8,2,2],
-"structspa__dict.html#a1f1083da3fcd51b9c3eb22cc8f1d54e0":[10,8,8,2,2,2],
-"structspa__dict.html#a3b3b78bfe5fffe13a10720bb7099c399":[10,8,8,2,2,1],
-"structspa__dict.html#a88aca003fcdbc47599ffb3e2737f1a69":[10,8,8,2,2,0],
-"structspa__dict__item.html":[10,8,8,2,1],
-"structspa__dict__item.html#a16dc8153e2ea77c9c82380456734478a":[10,8,8,2,1,0],
-"structspa__dict__item.html#af08479e3ff870039be002b436a02457d":[10,8,8,2,1,1],
-"structspa__dll.html":[11,0,180],
-"structspa__dll.html#a6e71bca8352ac6213b6d26c22732c9a1":[11,0,180,2],
-"structspa__dll.html#a7b2d7a0adb6cdc3680db685fef886d78":[11,0,180,1],
-"structspa__dll.html#a90a86177cee5a8c972d4a2825244d3de":[11,0,180,6],
-"structspa__dll.html#aa109171408f82fa3f287b70e2396ba42":[11,0,180,3],
-"structspa__dll.html#aa99d781b6e4c1133db7bef843fc4a21a":[11,0,180,4],
-"structspa__dll.html#ac3de731c327763f69c44e98224ee1068":[11,0,180,0],
-"structspa__dll.html#ae1e3a33d3f38548692173d283b613574":[11,0,180,5],
-"structspa__event.html":[10,8,0,15],
-"structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb":[10,8,0,15,1],
-"structspa__event.html#a2411141eed88d3587687a8d86c99d488":[10,8,0,15,0],
-"structspa__event__body.html":[10,8,0,14],
-"structspa__event__body.html#aa484bc2cadd16a104476183666de3819":[10,8,0,14,0],
-"structspa__fraction.html":[10,8,8,1,4],
-"structspa__fraction.html#a55246db96d647cd96be18983d59feb56":[10,8,8,1,4,0],
-"structspa__fraction.html#af099fb3a18c93ddac10239564da9de0c":[10,8,8,1,4,1],
-"structspa__graph.html":[10,8,5,3],
-"structspa__graph.html#a850c90822a1b32d7cd67ec5c76eda2fa":[10,8,5,3,0],
-"structspa__graph.html#a90439529765f13aadc6f1d7727244a1c":[10,8,5,3,3],
-"structspa__graph.html#a9bcd83554b53da4a139ed6a9be38bb1c":[10,8,5,3,1],
-"structspa__graph.html#aacd6dde80b95c6415d300f419ea6f144":[10,8,5,3,2],
-"structspa__graph__link.html":[10,8,5,2],
-"structspa__graph__link.html#a15313bfb8509b74448784ebf30f191c6":[10,8,5,2,1],
-"structspa__graph__link.html#ab1f910424f6a5ea5a34b52695536f53d":[10,8,5,2,0],
-"structspa__graph__link.html#ab7c807f9aaa9242cf8573b13212de674":[10,8,5,2,2],
-"structspa__graph__link.html#abf9a5059f5b888cf3a331832830f7373":[10,8,5,2,3],
-"structspa__graph__node.html":[10,8,5,5],
-"structspa__graph__node.html#a23c316f71a255a568e96092e72c40cae":[10,8,5,5,4],
-"structspa__graph__node.html#a6215edd0d426cfc8e697d648c09a4f57":[10,8,5,5,0],
-"structspa__graph__node.html#a6664b3c60baddc151a340bf2ebb3a5a2":[10,8,5,5,8],
-"structspa__graph__node.html#a7a4bea046f4d6a88d97e12a5297ed740":[10,8,5,5,1],
-"structspa__graph__node.html#ab16592a35d02f827271786b49110341c":[10,8,5,5,7],
-"structspa__graph__node.html#acbee04440eefb9b0a77f69ff1876dbc0":[10,8,5,5,6],
-"structspa__graph__node.html#acfb4e7658140701927336dee05ed1948":[10,8,5,5,3]
+"structspa__device__object__info.html#a9b6645d2c0b8b3679833ad122cb299a1":[10,8,4,5,2]
 };
