@@ -1,5 +1,6 @@
 var NAVTREEINDEX22 =
 {
+"structspa__meta__cursor.html#a46bdd5e6f3d880a74ae602e596176028":[10,8,1,12,3],
 "structspa__meta__cursor.html#a5f190ab6e828890a8c5b530cb9cae78d":[10,8,1,12,0],
 "structspa__meta__cursor.html#a78b7805e66e52164fc8a985578b4c990":[10,8,1,12,2],
 "structspa__meta__cursor.html#a9785c5b1408d2d4c4cc053bfb67ef6c0":[10,8,1,12,4],
@@ -248,6 +249,5 @@ var NAVTREEINDEX22 =
 "structspa__system__methods.html#a407f3e0b8a2fa54b40710d965ed83afc":[10,8,9,7,3,11],
 "structspa__system__methods.html#a448396798797647ebbf458fca65ef189":[10,8,9,7,3,12],
 "structspa__system__methods.html#a4a677665cdba24ec2faf6f471a919fa6":[10,8,9,7,3,17],
-"structspa__system__methods.html#a4cb1d67e7262f881d36b5c8a25f4d485":[10,8,9,7,3,16],
-"structspa__system__methods.html#a4cd27e2c3a8daa1705da0028af779060":[10,8,9,7,3,1]
+"structspa__system__methods.html#a4cb1d67e7262f881d36b5c8a25f4d485":[10,8,9,7,3,16]
 };
