@@ -1,5 +1,24 @@
 var NAVTREEINDEX7 =
 {
+"group__spa__cpu.html#ga34a7cfa724239e524fdccf570249abf3":[10,8,9,0,58],
+"group__spa__cpu.html#ga36f54e2aac3837cb3631db07cbfde3e2":[10,8,9,0,50],
+"group__spa__cpu.html#ga417908a823f8fc14cce2fa5ffc68aeb7":[10,8,9,0,24],
+"group__spa__cpu.html#ga43c86c77745486a5e63c4ac15f75875f":[10,8,9,0,8],
+"group__spa__cpu.html#ga4ae17a1d44999ba40d7006f4b78d7787":[10,8,9,0,14],
+"group__spa__cpu.html#ga51581ba204d019c69f5028919f32be27":[10,8,9,0,57],
+"group__spa__cpu.html#ga546bf71226a1fc712613f98e0009e30b":[10,8,9,0,44],
+"group__spa__cpu.html#ga550bc6f4afa17782e88306c89cd39663":[10,8,9,0,34],
+"group__spa__cpu.html#ga55a34f563b11a4022002c6bc810b02bc":[10,8,9,0,45],
+"group__spa__cpu.html#ga58a74b4c094d08b9f1d50d64ae59a757":[10,8,9,0,63],
+"group__spa__cpu.html#ga678997ea44550f4906f12306e8f43d76":[10,8,9,0,9],
+"group__spa__cpu.html#ga6cd931ac7d37bf2a2e4b311cc562cf38":[10,8,9,0,4],
+"group__spa__cpu.html#ga77813d1a6af8ee1d93c36fec332c389f":[10,8,9,0,60],
+"group__spa__cpu.html#ga7bf75d9047afb1801c025297f63b09cf":[10,8,9,0,5],
+"group__spa__cpu.html#ga7c2b2d8ee4d701b82ee6adce511f82af":[10,8,9,0,46],
+"group__spa__cpu.html#ga7d984f94a08720c709e38dc2b7f6055e":[10,8,9,0,16],
+"group__spa__cpu.html#ga7e84bb3a2f11a5a357ed8f79677234a8":[10,8,9,0,11],
+"group__spa__cpu.html#ga83e02f29ac1083c20ddabfa5c4825386":[10,8,9,0,42],
+"group__spa__cpu.html#ga858649645d60b353cf86ddb6ee41a445":[10,8,9,0,32],
 "group__spa__cpu.html#ga863ee498bc3630a98ee12fe569a9dc30":[10,8,9,0,10],
 "group__spa__cpu.html#ga898241b82efab179bd63ebea6c6e7d32":[10,8,9,0,39],
 "group__spa__cpu.html#ga8a8442eb592a7cb99c969edd45b55b01":[10,8,9,0,36],
@@ -50,39 +69,40 @@ var NAVTREEINDEX7 =
 "group__spa__dbus.html#gga39128520ce2167eb64279fc23e617fa0a4645a44a9d5954b882e7a3c23672fed8":[10,8,9,1,18,2],
 "group__spa__dbus.html#gga39128520ce2167eb64279fc23e617fa0a5fdca2872c84184d6a5ca0701726d229":[10,8,9,1,18,1],
 "group__spa__debug.html":[10,8,3],
-"group__spa__debug.html#ga0c0aff43e13b4501952801fa3be7b1b7":[10,8,3,27],
+"group__spa__debug.html#ga0c0aff43e13b4501952801fa3be7b1b7":[10,8,3,28],
 "group__spa__debug.html#ga16f96238e59068d1a7637230cb667412":[10,8,3,17],
-"group__spa__debug.html#ga17e8a8e1fb9113f5add80d0b1cfe9602":[10,8,3,23],
+"group__spa__debug.html#ga17e8a8e1fb9113f5add80d0b1cfe9602":[10,8,3,24],
 "group__spa__debug.html#ga20c14faa56c9f91aaccbc7b78bee4d75":[10,8,3,11],
-"group__spa__debug.html#ga26f0007da5add3060d00672939508d55":[10,8,3,32],
+"group__spa__debug.html#ga26f0007da5add3060d00672939508d55":[10,8,3,33],
 "group__spa__debug.html#ga33cb832be355e3f0a39d547fbd005735":[10,8,3,14],
-"group__spa__debug.html#ga38094276cb4dfb2190710683f4edc139":[10,8,3,21],
-"group__spa__debug.html#ga3e6c9fbc3e47f47500bf59145a8baadb":[10,8,3,34],
+"group__spa__debug.html#ga38094276cb4dfb2190710683f4edc139":[10,8,3,22],
+"group__spa__debug.html#ga3e6c9fbc3e47f47500bf59145a8baadb":[10,8,3,35],
 "group__spa__debug.html#ga3f8d824bf3268bbe885154db6a3a5215":[10,8,3,13],
-"group__spa__debug.html#ga43407166bdc04c3822b66257581fec18":[10,8,3,41],
-"group__spa__debug.html#ga43da221712a4457ff34457555d39b214":[10,8,3,36],
-"group__spa__debug.html#ga4b2e0edb1afe21a398be311ab6bde5b9":[10,8,3,37],
-"group__spa__debug.html#ga5eb6d7ec8b97e55331c9297a581800a5":[10,8,3,26],
-"group__spa__debug.html#ga6b44755735f4fdcce858fa6f97594b65":[10,8,3,22],
+"group__spa__debug.html#ga43407166bdc04c3822b66257581fec18":[10,8,3,42],
+"group__spa__debug.html#ga43da221712a4457ff34457555d39b214":[10,8,3,37],
+"group__spa__debug.html#ga4b2e0edb1afe21a398be311ab6bde5b9":[10,8,3,38],
+"group__spa__debug.html#ga5eb6d7ec8b97e55331c9297a581800a5":[10,8,3,27],
+"group__spa__debug.html#ga6b44755735f4fdcce858fa6f97594b65":[10,8,3,23],
 "group__spa__debug.html#ga6f983769067496ffae1b55d9a457384f":[10,8,3,18],
-"group__spa__debug.html#ga8907dcd66c24ffc68f2d328111428936":[10,8,3,39],
-"group__spa__debug.html#ga894c39341a4e23d74318af04868a71df":[10,8,3,38],
-"group__spa__debug.html#ga8ad92675783ea166fc2ea34dad54b75a":[10,8,3,40],
-"group__spa__debug.html#ga8bb3edd099bef82423cee5eff879c339":[10,8,3,28],
-"group__spa__debug.html#ga95e569a17a18eab8f646974d0b2cc136":[10,8,3,20],
+"group__spa__debug.html#ga8907dcd66c24ffc68f2d328111428936":[10,8,3,40],
+"group__spa__debug.html#ga894c39341a4e23d74318af04868a71df":[10,8,3,39],
+"group__spa__debug.html#ga8ad92675783ea166fc2ea34dad54b75a":[10,8,3,41],
+"group__spa__debug.html#ga8bb3edd099bef82423cee5eff879c339":[10,8,3,29],
+"group__spa__debug.html#ga95e569a17a18eab8f646974d0b2cc136":[10,8,3,21],
 "group__spa__debug.html#ga9d07bf77d70f8ccc9b1254e46a22a243":[10,8,3,16],
 "group__spa__debug.html#ga9df460de860ee08b42581d9846960494":[10,8,3,12],
-"group__spa__debug.html#gaa00cdef782319e1a9ae738ffb9422506":[10,8,3,35],
-"group__spa__debug.html#gac0431ebc7981b41690e6356925bcc954":[10,8,3,42],
-"group__spa__debug.html#gac394fa61f7506be415fd8c0b6e422c6a":[10,8,3,33],
-"group__spa__debug.html#gac6f960544afa686154bfebae8c42406b":[10,8,3,43],
+"group__spa__debug.html#gaa00cdef782319e1a9ae738ffb9422506":[10,8,3,36],
+"group__spa__debug.html#gac0431ebc7981b41690e6356925bcc954":[10,8,3,43],
+"group__spa__debug.html#gac394fa61f7506be415fd8c0b6e422c6a":[10,8,3,34],
+"group__spa__debug.html#gac6f960544afa686154bfebae8c42406b":[10,8,3,44],
 "group__spa__debug.html#gad9d0f508b3ec1caafca4e66dc51cd5b5":[10,8,3,15],
-"group__spa__debug.html#gae0fd7bbdbaad907ad5b923053f888dca":[10,8,3,30],
-"group__spa__debug.html#gaeec0bfa08b41f3002b60ed2e997cabbe":[10,8,3,25],
-"group__spa__debug.html#gaef7cbb7d8a18d32656a9149cd4fdfd6d":[10,8,3,24],
+"group__spa__debug.html#gae0fd7bbdbaad907ad5b923053f888dca":[10,8,3,31],
+"group__spa__debug.html#gae1e8aa2eeedd2ccee01c23637d93fefb":[10,8,3,20],
+"group__spa__debug.html#gaeec0bfa08b41f3002b60ed2e997cabbe":[10,8,3,26],
+"group__spa__debug.html#gaef7cbb7d8a18d32656a9149cd4fdfd6d":[10,8,3,25],
 "group__spa__debug.html#gaf6cbda715cf394fce2121122f2f3b9ed":[10,8,3,19],
-"group__spa__debug.html#gafaccba3f44098f680e755ad34b421de0":[10,8,3,29],
-"group__spa__debug.html#gafb77a961ae0c0be0034f2a1b4f264ee9":[10,8,3,31],
+"group__spa__debug.html#gafaccba3f44098f680e755ad34b421de0":[10,8,3,30],
+"group__spa__debug.html#gafb77a961ae0c0be0034f2a1b4f264ee9":[10,8,3,32],
 "group__spa__device.html":[10,8,4],
 "group__spa__device.html#ga0176aee6eac7ee89895ab4f4069afa41":[10,8,4,44],
 "group__spa__device.html#ga020999d4feb921cd73b094b826a99d32":[10,8,4,61],
@@ -229,25 +249,5 @@ var NAVTREEINDEX7 =
 "group__spa__hooks.html#ga58d3375750cb16ee5dbcb8337af46cba":[10,8,8,4,6],
 "group__spa__hooks.html#ga63c54fcf4a4073e230e656f3275ebaea":[10,8,8,4,16],
 "group__spa__hooks.html#ga85ae35aa8df17a38bcc003e0a05e73cc":[10,8,8,4,3],
-"group__spa__hooks.html#ga9fb6df7a8c2a772b0cc39f81bc0eec03":[10,8,8,4,9],
-"group__spa__hooks.html#gab5d20379dc8a8a17e58631045e3f6323":[10,8,8,4,13],
-"group__spa__hooks.html#gacb30a0a53954eed2af8041a1882eef15":[10,8,8,4,14],
-"group__spa__hooks.html#gacbc74f9ceab3dc7c5d6d8c3eca6a41e5":[10,8,8,4,12],
-"group__spa__hooks.html#gadb7d27ebaa8d5997c5420910de1db773":[10,8,8,4,4],
-"group__spa__hooks.html#gaddde6a682396fb0125849ed615c8d0c5":[10,8,8,4,7],
-"group__spa__hooks.html#gae70f84c0eb2bae8f5d08eb694969dd40":[10,8,8,4,15],
-"group__spa__i18n.html":[10,8,9,2],
-"group__spa__i18n.html#gaa4c021574498780906bcc3f2958cc23f":[10,8,9,2,7],
-"group__spa__i18n.html#gab6c7211ad9795cf4c1c55487c165a555":[10,8,9,2,4],
-"group__spa__i18n.html#gacc03db6ab5181108527ca45e7674b235":[10,8,9,2,3],
-"group__spa__i18n.html#gaf3aa0f8921abf9d572c9fde4a9d0825d":[10,8,9,2,5],
-"group__spa__i18n.html#gafe48fd94d55ba3db8f10fb1550ec79c8":[10,8,9,2,6],
-"group__spa__interfaces.html":[10,8,8,5],
-"group__spa__interfaces.html#ga0b43b5a0ee8aa8f305d0c9971716e5b0":[10,8,8,5,17],
-"group__spa__interfaces.html#ga12d9c46094ccfe8448e2d592cc8f457b":[10,8,8,5,18],
-"group__spa__interfaces.html#ga1566a7843972b177af627e6e16b86c26":[10,8,8,5,13],
-"group__spa__interfaces.html#ga1facc1b12f5dfb7e3362e9f1a6d3cb6c":[10,8,8,5,15],
-"group__spa__interfaces.html#ga333235e7b2636c920cfa766481e59729":[10,8,8,5,16],
-"group__spa__interfaces.html#ga48dc1c688fd324d08a3eed9684abf41a":[10,8,8,5,8],
-"group__spa__interfaces.html#ga5f51d2f3b4df5eb44fa6163ba3958f5d":[10,8,8,5,7]
+"group__spa__hooks.html#ga9fb6df7a8c2a772b0cc39f81bc0eec03":[10,8,8,4,9]
 };
